@@ -42,24 +42,24 @@ class Foo(Configurable):
 
     """
 
-    i = Int(0, config=True, help="The integer i.")
-    j = Int(1, config=True, help="The integer j.")
-    name = Unicode(u'Brian', config=True, help="First name.")
+    i = Int(0, help="The integer i.").tag(config=True)
+    j = Int(1, help="The integer j.").tag(config=True)
+    name = Unicode(u'Brian', help="First name.").tag(config=True)
 
 
 class Bar(Configurable):
 
-    enabled = Bool(True, config=True, help="Enable bar.")
+    enabled = Bool(True, help="Enable bar.").tag(config=True)
 
 
 class MyApp(Application):
 
     name = Unicode(u'myapp')
-    running = Bool(False, config=True,
-                   help="Is the app running?")
+    running = Bool(False, 
+                   help="Is the app running?").tag(config=True)
     classes = List([Bar, Foo])
-    config_file = Unicode(u'', config=True,
-                   help="Load this config file")
+    config_file = Unicode(u'', 
+                   help="Load this config file").tag(config=True)
     
     aliases = Dict(dict(i='Foo.i',j='Foo.j',name='Foo.name', running='MyApp.running',
                         enabled='Bar.enabled', log_level='MyApp.log_level'))
